Module: Holidays::Definition::CustomMethods::KR

Defined in:
lib/holidays/definition/custom_methods/kr.rb

Overview

kr custom holiday calculations, ported verbatim from the methods: block in definitions/kr.yaml.

Class Method Summary collapse

Class Method Details

.kr_seollal_eve(year, region) ⇒ Object

Seollal eve is the day before Seollal (Korean New Year), which is the first day of the first lunar month.



10
11
12
# File 'lib/holidays/definition/custom_methods/kr.rb', line 10

def kr_seollal_eve(year, region)
  Holidays::Factory::Definition.custom_methods_repository.find("lunar_to_solar(year, month, day, region)").call(year, 1, 1, region) - 1
end